@@ -38,6 +38,8 @@ class Element(CoreElement):
         self.inner_text = inner_text
         self.self_closing_tag = self_closing_tag
         setattr(self, '_inner_elements', []) 
+        setattr(self, '_prev_elements', []) 
+        setattr(self, '_next_elements', []) 
     
     def get_html(self):
         """Generate html string
