@@ -1,7 +1,7 @@
 from flask_uio import Element
 import pytest
 
-def test_create_element_has_attributes():
+def test_has_attributes_when_create_an_element():
     div = Element('div')
     assert hasattr(div, 'tag_name')
     assert hasattr(div, 'css_class')
@@ -10,69 +10,95 @@ def test_create_element_has_attributes():
     assert hasattr(div, '_inner_elements')
     assert hasattr(div, '_prev_elements')
     assert hasattr(div, '_next_elements')
-    assert hasattr(div, 'is_self_closing_tag')
+    assert hasattr(div, 'self_closing_tag')
     assert hasattr(div, 'hide_id')
 
-testelement = Element('span', inner_text='Element for testing')
 testcase1 = [
     (
         Element('div'), 
         {
             'tag_name': 'div',
+            'hide_id': True,
+            'attrs': {},
             'css_class': None,
-            'attrs': [],
             'inner_text': None,
+            'self_closing_tag': False,
             '_inner_elements': [],
             '_prev_elements': [],
             '_next_elements': [],
-            'is_self_closing_tag': False,
-            'hide_id': True,
         }
     ),
     (
-        Element('div', 
-            css_class='ui container', 
-            inner_text='Test UI container', 
-            inner_elements=[testelement],
-            prev_elements=[testelement],
-            next_elements=[testelement],
-            attrs=[('style', 'margin: 40px;')],
-            hide_id=False,
-        ), 
+        Element('span', 'testing'),
+        {
+            'tag_name': 'span',
+            'hide_id': True,
+            'attrs': {},
+            'css_class': None,
+            'inner_text': 'testing',
+            'self_closing_tag': False,
+            '_inner_elements': [],
+            '_prev_elements': [],
+            '_next_elements': [],
+        }
+    ),
+    (
+        Element('div', 'testing', False),
         {
             'tag_name': 'div',
-            'css_class': 'ui container',
-            'attrs': [('style', 'margin: 40px;')],
-            'inner_text': 'Test UI container',
-            '_inner_elements': [testelement],
-            '_prev_elements': [testelement],
-            '_next_elements': [testelement],
-            'is_self_closing_tag': False,
             'hide_id': False,
+            'attrs': {},
+            'css_class': None,
+            'inner_text': 'testing',
+            'self_closing_tag': False,
+            '_inner_elements': [],
+            '_prev_elements': [],
+            '_next_elements': [],
+        }
+    ),
+    (
+        Element('br', self_closing_tag=True),
+        {
+            'tag_name': 'br',
+            'hide_id': True,
+            'attrs': {},
+            'css_class': None,
+            'inner_text': None,
+            'self_closing_tag': True,
+            '_inner_elements': [],
+            '_prev_elements': [],
+            '_next_elements': [],
+        }
+    ),
+    (
+        Element('form', _class='ui form', _method='POST', _action='index.php'),
+        {
+            'tag_name': 'form',
+            'hide_id': True,
+            'attrs': {'_class': 'ui form', '_method': 'POST', '_action':'index.php'},
+            'css_class': 'ui form',
+            'inner_text': None,
+            'self_closing_tag': False,
+            '_inner_elements': [],
+            '_prev_elements': [],
+            '_next_elements': [],
         }
     )
 ]
 @pytest.mark.parametrize('test, expect', testcase1)
-def test_default_value(test, expect):
+def test_element_has_valid_attribute_value(test, expect):
     assert getattr(test, 'tag_name') == expect['tag_name']
-    assert getattr(test, 'css_class') is expect['css_class']
+    assert getattr(test, 'hide_id') == expect['hide_id']
     assert getattr(test, 'attrs') == expect['attrs']
+    assert getattr(test, 'css_class') is expect['css_class']
     assert getattr(test, 'inner_text') is expect['inner_text']
+    assert getattr(test, 'self_closing_tag') == expect['self_closing_tag']
     assert getattr(test, '_inner_elements') == expect['_inner_elements']
     assert getattr(test, '_prev_elements') == expect['_prev_elements']
     assert getattr(test, '_next_elements') == expect['_next_elements']
-    assert getattr(test, 'is_self_closing_tag') == expect['is_self_closing_tag']
-    assert getattr(test, 'hide_id') == expect['hide_id']
-    inner_elements = getattr(test, '_inner_elements')
-    if len(inner_elements) > 0:
-        assert getattr(test, '_inner_elements')[0] == expect['_inner_elements'][0]
-    prev_elements = getattr(test, '_prev_elements')
-    if len(prev_elements) > 0:
-        assert getattr(test, '_prev_elements')[0] == expect['_prev_elements'][0]
-    next_elements = getattr(test, '_next_elements')
-    if len(next_elements) > 0:
-        assert getattr(test, '_next_elements')[0] == expect['_next_elements'][0]
-        
+
+testelement = Element('span', inner_text='Element for testing')
+
 def test_append():
     e = Element('div')
     e.append(testelement)
@@ -114,51 +140,27 @@ def test_find_element():
 testcase2 = [
     (
         Element('div',
-            css_class='ui segment',
+            _class='ui segment',
             inner_text='hello world',
         ),
         '<div class="ui segment">hello world</div>'
     ),
     (
         Element('input',
-            css_class='ui input',
-            attrs=[('type', 'email'), ('name', 'email_address'), ('required', None)],
+            _class='ui input',
+            _type='email',
+            _name='email_address',
+            _required=True,
             hide_id=False,
         ),
-        '<input id="replaced_id" class="ui input" type="email" name="email_address" required></input>'
+        '<input id="replaced_id" class="ui input" type="email" name="email_address" required="True"></input>'
     ),
     (
-        Element('div',
-            css_class='ui basic segment',
-            inner_elements=[
-                Element('h1', inner_text='FlaskUIO'),
-                Element('p', inner_text='Testing flask_uio', css_class='custom'),
-            ]
-        ),
-        '<div class="ui basic segment"><h1>FlaskUIO</h1><p class="custom">Testing flask_uio</p></div>'
-    ),
-    (
-        Element('div',
-            css_class='ui basic segment',
-            inner_elements=[Element('h1', inner_text='FlaskUIO')],
-            prev_elements=[Element('p', inner_text='Testing flask_uio', css_class='custom')]
-        ),
-        '<p class="custom">Testing flask_uio</p><div class="ui basic segment"><h1>FlaskUIO</h1></div>'
-    ),
-    (
-        Element('div',
-            css_class='ui basic segment',
-            inner_elements=[Element('h1', inner_text='FlaskUIO')],
-            next_elements=[Element('p', inner_text='Testing flask_uio', css_class='custom')]
-        ),
-        '<div class="ui basic segment"><h1>FlaskUIO</h1></div><p class="custom">Testing flask_uio</p>'
-    ),
-    (
-        Element('br', is_self_closing_tag=True),
+        Element('br', self_closing_tag=True),
         '<br />'
     ),
     (
-        Element('input', attrs=[('type', 'text'), ('value', 'some value'), ('name', 'txt1')], hide_id=False, is_self_closing_tag=True),
+        Element('input', _type='text', _value='some value', _name='txt1', hide_id=False, self_closing_tag=True),
         '<input id="replaced_id" type="text" value="some value" name="txt1" />'
     )
 ]
